@@ -1,9 +1,9 @@
 <?php
-// $Horde: kronolith/lib/base.php,v 1.29 2001/11/07 09:21:31 chuck Exp $
-
-/*
+/**
  * Kronolith base inclusion file.
  *
+ * $Horde: kronolith/lib/base.php,v 1.34.2.8 2003/04/04 19:24:00 chuck Exp $
+ *
  * This file brings in all of the dependencies that every Kronolith
  * script will need, and sets up objects that all scripts use.
  */
@@ -16,10 +16,10 @@
 
 // Browser detection library
 require_once HORDE_BASE . '/lib/Browser.php';
-$browser = new Browser();
+$browser = &new Browser();
 if ($browser->hasQuirk('cache_ssl_downloads')
-    && isset($HTTP_SERVER_VARS['HTTPS'])
-    && ($HTTP_SERVER_VARS['HTTPS'] == 'on')) {
+    && isset($_SERVER['HTTPS'])
+    && ($_SERVER['HTTPS'] == 'on')) {
     session_cache_limiter('private, must-revalidate');
 }
 
@@ -28,6 +28,7 @@ require_once HORDE_BASE . '/lib/Registry.php';
 $registry = &Registry::singleton();
 $registry->pushApp('kronolith');
 $conf = &$GLOBALS['conf'];
+@define('KRONOLITH_TEMPLATES', $registry->getParam('templates'));
 
 // set error reporting according to config settings
 error_reporting($conf['debug_level']);
@@ -42,26 +43,34 @@ require_once HORDE_BASE . '/lib/Auth.php';
 // Kronolith base library
 require_once KRONOLITH_BASE . '/lib/Kronolith.php';
 
+// Don't allow access unless there is a Horde login
+if (!Auth::getAuth()) {
+    $url = Horde::url($registry->getParam('webroot', 'horde') . '/login.php', true);
+    header('Location: ' . Kronolith::addParameter($url, 'url=' . urlencode($_SERVER['PHP_SELF'])));
+    exit;
+}
+
 // Help
 require_once HORDE_BASE . '/lib/Help.php';
 
+// Notification sytem
+require_once HORDE_BASE . '/lib/Notification.php';
+require_once KRONOLITH_BASE . '/lib/Notification/kronolith.php';
+$notification = &Notification::singleton();
+$notification->attach('status', null, 'Notification_status_kronolith');
+
 // PEAR Date_Calc
 require_once 'Date/Calc.php';
 
-// Don't allow access unless there is a Horde login
-if (!Auth::getAuth()) {
-    header('Location: ' . Horde::url($registry->getWebRoot("horde") . '/login.php?url=' . urlencode($HTTP_SERVER_VARS['PHP_SELF']), true));
-    exit;
-}
-
 // Set the timezone variable, if available.
 $timezone = $GLOBALS['prefs']->getValue('timezone');
-if (isset($timezone)) {
+if (!empty($timezone)) {
     putenv('TZ=' . $timezone);
 }
 
 // Open the users calendar
 $GLOBALS['calendar'] = &Kronolith_Driver::factory($conf['calendar']['driver'], $conf['calendar']['params']);
+if ($GLOBALS['calendar'] === false) {
+    Horde::fatal(PEAR::raiseError(_("Unable to create calendar instance.")), __FILE__, __LINE__);
+}
 $GLOBALS['calendar']->open(Auth::getAuth());
-
-?>
